Quirk: Quantum Circuit Simulator
Description: Quirk is an open-source drag-and-drop quantum circuit simulator for exploring and understanding small quantum circuits.
Keywords: quantum,circuit,simulator,quirk

Version 2.3
Escaped Link - Link to current circuit, without special characters that confuse forums.
Offline Copy - Html file containing Quirk and the current circuit.
Circuit JSON - Parsable representation of current circuit.

OpenQASM

Simulation Data JSON - Output amplitudes, detector results, display data, etc.
Skip output amplitudes

From Rotation |  | From Matrix |  | From Circuit
--- | --- | --- | --- | ---
axis ° angle ° global phase |  | ensure unitary (by SVD) |  | From part of current circuit: column range wire range Inputs: (none), Weight: 0
| OR |  | OR |
circuit symbol |  | circuit symbol |  | circuit symbol

An error happened. :(
See more / complain about this issue on github.
Please report it:

- Create an issue on github (requires an account) (repository: Strilanc/Quirk)
- or

Useful details to mention (auto-included if you use the create/email links above):
PRE-DRAWN
POST-DRAWN
You appear to have JavaScript blocked. And Quirk is made out of JavaScript... :(